aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--register.h19
-rw-r--r--ui/gtk/about_dlg.c7
-rw-r--r--ui/gtk/main.c2
-rw-r--r--ui/qt/splash_overlay.cpp5
-rw-r--r--wireshark-qt.cpp2
5 files changed, 23 insertions, 12 deletions
diff --git a/ui/gtk/about_dlg.c b/ui/gtk/about_dlg.c
index aee4b171d2..b7b3bb1000 100644
--- a/ui/gtk/about_dlg.c
+++ b/ui/gtk/about_dlg.c
@@ -233,6 +233,9 @@ splash_update(register_action_e action, const char *message, gpointer client_dat
case RA_PREFERENCES:
action_msg = "Loading module preferences ...";
break;
+ case RA_INTERFACES:
+ action_msg = "Finding local interfaces ...";
+ break;
case RA_CONFIGURATION:
action_msg = "Loading configuration files ...";
break;
@@ -245,10 +248,10 @@ splash_update(register_action_e action, const char *message, gpointer client_dat
}
if(ul_count == 0) { /* get the count of dissectors */
- ul_count = register_count() + 6; /* additional 6 for:
+ ul_count = register_count() + 7; /* additional 7 for:
dissectors, listeners,
registering plugins, handingoff plugins,
- preferences and configuration */
+ preferences, interfaces and configuration */
#ifdef HAVE_LUA
ul_count += wslua_count_plugins (); /* get count of lua plugins */
#endif
diff --git a/ui/gtk/main.c b/ui/gtk/main.c
index e7d37df5cd..623b092493 100644
--- a/ui/gtk/main.c
+++ b/ui/gtk/main.c
@@ -2361,6 +2361,8 @@ main(int argc, char *argv[])
commandline_other_options(argc, argv, &commandline_info, TRUE);
#ifdef HAVE_LIBPCAP
+ splash_update(RA_INTERFACES, NULL, (gpointer)splash_win);
+
fill_in_local_interfaces(main_window_update);
if (commandline_info.start_capture || commandline_info.list_link_layer_types) {
diff --git a/ui/qt/splash_overlay.cpp b/ui/qt/splash_overlay.cpp
index fec318607a..d8f6d34cd7 100644
--- a/ui/qt/splash_overlay.cpp
+++ b/ui/qt/splash_overlay.cpp
@@ -55,7 +55,7 @@ SplashOverlay::SplashOverlay(QWidget *parent) :
// Number of register action transitions (e.g. RA_NONE -> RA_DISSECTORS,
// RA_DISSECTORS -> RA_PLUGIN_REGISTER) minus two.
- int register_add = 4;
+ int register_add = 5;
#ifdef HAVE_LUA
register_add += wslua_count_plugins(); /* get count of lua plugins */
#endif
@@ -159,6 +159,9 @@ void SplashOverlay::splashUpdate(register_action_e action, const char *message)
case RA_PREFERENCES:
action_msg = tr("Loading module preferences");
break;
+ case RA_INTERFACES:
+ action_msg = tr("Finding local interfaces");
+ break;
case RA_CONFIGURATION:
action_msg = tr("Loading configuration files");
break;
diff --git a/wireshark-qt.cpp b/wireshark-qt.cpp
index 4268257a31..015706d5cc 100644
--- a/wireshark-qt.cpp
+++ b/wireshark-qt.cpp
@@ -617,6 +617,8 @@ int main(int argc, char *argv[])
timestamp_set_seconds_type (recent.gui_seconds_format);
#ifdef HAVE_LIBPCAP
+ splash_update(RA_INTERFACES, NULL, NULL);
+
fill_in_local_interfaces(main_window_update);
if (commandline_info.start_capture || commandline_info.list_link_layer_types) {
diff --git a/register.h b/register.h
index 9e19696574..ece6003090 100644
--- a/register.h
+++ b/register.h
@@ -32,17 +32,18 @@ extern "C" {
#include <glib.h>
typedef enum {
- RA_NONE, /* for initialization */
+ RA_NONE, /* For initialization */
RA_DISSECTORS, /* Initializing dissectors */
RA_LISTENERS, /* Tap listeners */
- RA_REGISTER, /* register */
- RA_PLUGIN_REGISTER, /* plugin register */
- RA_HANDOFF, /* handoff */
- RA_PLUGIN_HANDOFF, /* plugin handoff */
- RA_LUA_PLUGINS, /* lua plugin register */
- RA_LUA_DEREGISTER, /* lua plugin deregister */
- RA_PREFERENCES, /* module preferences */
- RA_CONFIGURATION /* configuration files */
+ RA_REGISTER, /* Built-in register */
+ RA_PLUGIN_REGISTER, /* Plugin register */
+ RA_HANDOFF, /* Built-in handoff */
+ RA_PLUGIN_HANDOFF, /* Plugin handoff */
+ RA_LUA_PLUGINS, /* Lua plugin register */
+ RA_LUA_DEREGISTER, /* Lua plugin deregister */
+ RA_PREFERENCES, /* Module preferences */
+ RA_INTERFACES, /* Local interfaces */
+ RA_CONFIGURATION /* Configuration files */
} register_action_e;
typedef void (*register_cb)(register_action_e action, const char *message, gpointer client_data);